@@ -157,6 +157,14 @@ class TestBigQuery(Validator):
             },
         )
 
+        self.validate_all(
+            "DIV(x, y)",
+            write={
+                "bigquery": "DIV(x, y)",
+                "duckdb": "CAST(x / y AS INT)",
+            },
+        )
+
         self.validate_identity(
             "SELECT ROW() OVER (y ROWS BETWEEN 1 PRECEDING AND 1 FOLLOWING) FROM x WINDOW y AS (PARTITION BY CATEGORY)"
         )
@@ -284,4 +292,6 @@ class TestBigQuery(Validator):
             "CREATE TEMPORARY FUNCTION a(x FLOAT64, y FLOAT64) RETURNS FLOAT64 NOT DETERMINISTIC LANGUAGE js AS 'return x*y;'"
         )
         self.validate_identity("CREATE TEMPORARY FUNCTION a(x FLOAT64, y FLOAT64) AS ((x + 4) / y)")
-        self.validate_identity("CREATE TABLE FUNCTION a(x INT64) RETURNS TABLE <q STRING, r INT64> AS SELECT s, t")
+        self.validate_identity(
+            "CREATE TABLE FUNCTION a(x INT64) RETURNS TABLE <q STRING, r INT64> AS SELECT s, t"
+        )
