@@ -287,3 +287,31 @@ SELECT
       "fffffff"
     )
   );
+/*
+  multi
+  line
+  comment
+*/
+SELECT * FROM foo;
+/*
+  multi
+  line
+  comment
+*/
+SELECT
+  *
+FROM foo;
+SELECT x FROM a.b.c /*x*/, e.f.g /*x*/;
+SELECT
+  x
+FROM a.b.c /* x */, e.f.g /* x */;
+SELECT x FROM (SELECT * FROM bla /*x*/WHERE id = 1) /*x*/;
+SELECT
+  x
+FROM (
+  SELECT
+    *
+  FROM bla /* x */
+  WHERE
+    id = 1
+) /* x */;
